@@ -1,5 +1,5 @@
 """Contains exceptions that are raised when errors occur with config files."""
-from autoconfiguration.exceptions.base_exception import ConfigBaseError
+from autoconfiguration.exceptions.base_error import ConfigBaseError
 
 
 class NoConfigFilesFoundError(ConfigBaseError):
